import { __decorate } from "tslib";
import { Controller, eventListener, extractEventTargets } from '@a11d/lit';
import { ResizeController } from '@3mo/resize-observer';
import { Throttler } from '@3mo/throttler';
function target() {
    return extractEventTargets(this.host, this.options?.target);
}
export class PointerHoverController extends Controller {
    get hover() { return this._hover; }
    constructor(host, options) {
        super(host);
        this.host = host;
        this.options = options;
        this._hover = false;
        this.throttler = new Throttler(10);
        this.resizeController = new ResizeController(this.host, {
            target: this.host,
            callback: () => this.checkHover()
        });
    }
    async checkHover() {
        await this.throttler.throttle();
        const elements = await extractEventTargets(this.host, this.options?.target);
        const hover = elements.some(e => e.matches(':hover'));
        if (this._hover !== hover) {
            this._hover = hover;
            this.options?.handleHoverChange?.(hover);
            this.host.requestUpdate();
        }
    }
}
__decorate([
    eventListener({ type: 'pointerenter', target }),
    eventListener({ type: 'pointerleave', target }),
    eventListener({ type: 'pointerdown', target: document }),
    eventListener({ type: 'pointerup', target: document }),
    eventListener({ type: 'pointercancel', target: document })
], PointerHoverController.prototype, "checkHover", null);
